﻿

using System;
using System.Collections.Generic;
using System.IO;
using System.Windows;
using NLog;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Wpf;

namespace _20190218_TicketViewAnalyseTerre
{
    /// <summary>
    /// Logique d'interaction pour MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private CoucheFactory _factoryLayer;
        private readonly Logger _logger = NLog.LogManager.GetCurrentClassLogger();

        public MainWindow()
        {
            InitializeComponent();
        }

        private void Map1_Loaded(object sender, RoutedEventArgs e)
        {
            try
            {
                var couchesACharger = ChargerCouchesXml();
                var factoryRaster = new CoucheFactory(couchesACharger,
                    new List<ConstantsMap.TypeCouche>() {ConstantsMap.TypeCouche.raster});
                _factoryLayer = new CoucheFactory(couchesACharger,
                    new List<ConstantsMap.TypeCouche>() {ConstantsMap.TypeCouche.shp, ConstantsMap.TypeCouche.sql});

                Map1.MapUnit = GeographyUnit.Meter;
                Map1.Overlays.Add(ConstantsMap.NOMOVERLAYRASTER + "_KEY",
                    InitialiserOverlayRaster(factoryRaster.Layers));
                Map1.Overlays.Add(ConstantsMap.NOMOVERLAYLAYER + "_KEY", InitialiserOverlayLayer(_factoryLayer.Layers));
                var bbox = new RectangleShape(614999.75, 6670001.25, 619999.75, 6665001.25);
                Map1.CurrentExtent = bbox.GetBoundingBox();

                Map1.Refresh();
                _logger.Info("Hello World");
            }
            catch (Exception ex)
            {
                _logger.Info(ex.Message);
                _logger.Info(ex.StackTrace);
                _logger.Info(ex.InnerException);
            }
        }

        private XmlCoucheCollection ChargerCouchesXml()
        {
            var fichierXml = Path.Combine(Directory.GetCurrentDirectory(), ConstantsMap.FICHIERXML);
            if (!File.Exists(fichierXml))
                throw new FileNotFoundException("Fichier Xml pour chargement des couches non trouvé");

            return XmlCoucheSerializer.DeserialiserXml(fichierXml);
        }

        private LayerOverlay InitialiserOverlayRaster(IEnumerable<Layer> layers)
        {
            var ovLy = new LayerOverlay
            {
                TileHeight = 256,
                TileWidth = 256,
                TileBuffer = 2,
                TileType = TileType.HybridTile,
                TileCache = new FileBitmapTileCache(@"CacheRaster\", "ManualCache"),
                DrawingQuality = DrawingQuality.HighSpeed
            };
            ovLy.TileBuffer = 2;

            ovLy.Name = ConstantsMap.NOMOVERLAYRASTER;
            return InitialiserOverlay(ovLy, layers);
        }

        private LayerOverlay InitialiserOverlayLayer(IEnumerable<Layer> layers)
        {
            var ovLy = new LayerOverlay
            {
                TileType = TileType.SingleTile,
                Name = ConstantsMap.NOMOVERLAYLAYER
            };
            return InitialiserOverlay(ovLy, layers);
        }


        private LayerOverlay InitialiserOverlay(LayerOverlay ovLayer, IEnumerable<Layer> layers)
        {
            foreach (var c in layers)
            {
                ovLayer.Layers.Add(c);
            }

            return ovLayer;
        }
    }
}
